# Minimal slide demo

Some Author [1]
Some Author2 [2, 3] (`someemail at site.net`)
[1] UiO
[2] institution1
[3] institution2

#### Apr 15, 2021

# Table of contents

# Commands to be commented out

Scope Focus Approach |

Methods are slow or fast:

- Slow:

- Pick-and-choose

- Fast:

- Quickstep

- MMST

# Chapters and Sections

# Section 1

## Subsection 1

Abstract. on two lines

## subsection

### subsubsection

Horizontal rule:

## Media

Figure 1: Results for \( a=2 \).

## Inline Tags

normal text on top

This text has one, two, three lines

Inline Mathematics: \( a^2=\sin(x) \).

Paragraph with running.. text

Only Paragraph. Some Italics with text Only *Italics* italics-with hyphen-emphasis

Some Bold with text Only Bold Bold-with hyphen-Bold

No newline after this. The text continues on two more lines.

more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text more text

blank line, even more text

## Inline Tags 2

inline comment here (Alessandro 1: has a comment)

### Subsubsection

text with a line-
break normal text

url with verbatim: `verbatim`

non-breaking space using tilde: 7.4 km

Guns & Roses

Texas A&M

emoji:

test footnotes [1]

1: Typesetting of the footnote depends on the format.

## Commands

a ref: 1

Here is a citation using cite: [1] Four citations: [2] [3] [4] [1]

nested list:TODO

- item1

- item2

- item3 which continues on the next line to test that feature

- and a sublist

- with indented subitem1

- and a subitem2

- and perhaps an ordered sublist

- first item

- second item, continuing on a new line

keyword1:

  TODO explanation of keyword1

keyword2:

  explanation of keyword2

tables

time | velocity | acceleration
--- | --- | ---
0.0 | 1.4186 | -5.01
2.0 | 1.376512 | 11.919

## Code

Verbatim above `pycod -t`

    total = 0

Verbatim below `pycod -t`

# Blocks

!bquote A quote:

> Sayre's law states that "in any dispute the intensity of feeling is inversely proportional to the value of the issues at stake."
> By way of corollary, it adds:
> "That is why academic politics are so bitter."
> Source: wikipedia

!bbox and !bt.

A generic equation

$$ f(x) = 0 $$

must be solved by a numerical method, such as

- Newton's method

- The Bisection method

- Fixed-point (Picard) iteration by rewriting \( f(x)=x - g(x) \)

- The Secant method

!bwarning.

Watch out for \( \nabla\cdot\boldsymbol{u}=0 \) equations

Divergence freedom is often problematic from a numerical point of view.

## References

1. H. P. Langtangen and G. Pedersen. Propagation of Large Destructive Waves, International Journal of Applied Mechanics and Engineering, 7(1), pp. 187-204, 2002.

2. H. P. Langtangen. Stochastic Breakthrough Time Analysis of an Enhanced Oil Recovery Process, SIAM Journal on Scientific Computing, 13, pp. 1394-1417, 1992.

3. H. P. Langtangen. Numerical Solution of First Passage Problems in Random Vibrations, SIAM Journal of Scientific and Statistical Computing, 15, pp. 997-996, 1994.

4. M. Mortensen, H. P. Langtangen and G. N. Wells. A FEniCS-Based Programming Framework for Modeling Turbulent Flow by the Reynolds-Averaged Navier-Stokes Equations, Advances in Water Resources, 34(9), doi: 10.1016/j.advwatres.2011.02.013, 2011.